.. _tensor-array:

N-dim array
===========

.. automodule:: sympy.tensor.array


.. autoclass:: ImmutableDenseNDimArray
   :members:

.. autoclass:: ImmutableSparseNDimArray
   :members:

.. autoclass:: MutableDenseNDimArray
   :members:

.. autoclass:: MutableSparseNDimArray
   :members:
